<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Information</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Oversættere</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1-browser til SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Mobil udgave</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Kompileret ved brug af Qt %1 (med %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Besøg vores websted for opdateringer:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Mange mennesker har bidraget med oversættelser.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Du kan også hjælpe med at oversætte SMTube til dit eget sprog.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Besøg %1 og meld dig til et oversættelsesteam.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Klik her for at se oversætterne fra Transifex-teams</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="112"/>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="115"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="123"/>
        <source>Zoom +</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="127"/>
        <source>Zoom -</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="131"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="134"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="146"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>Toolbar</source>
        <translation>Værktøjslinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="151"/>
        <source>Statusbar</source>
        <translation>Statuslinje</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="155"/>
        <source>&amp;Settings</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="167"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>&amp;Opdater understøttelse af YouTube-afspilning</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="169"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>&amp;Installer/opdater understøttelse af YouTube-afspilning</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="175"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;Om SMTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="296"/>
        <source>Download video using an external service</source>
        <translation>Download video ved brug af en ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="297"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="524"/>
        <source>No video found</source>
        <translation>Der blev ikke fundet nogen video</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="525"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Det var ikke muligt at finde videoens URL.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="282"/>
        <source>Loading... %1%</source>
        <translation>Indlæser ... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>Downloader ...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>Opretter forbindelse til %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>YouTube-koden er blevet installeret.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>Installeret version: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>Det er ikke muligt at gemme %1.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Der opstod en fejl ved download af filen:&lt;br&gt;%1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation>%1 kunne ikke kommunikere med youtube-dl. Enten er den ikke downloadet eller også virker den ikke korrekt.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Det var ikke muligt at finde videoens URL.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation>Måske er det nødvendigt at opdatere youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <location filename="../codedownloader.cpp" line="208"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation>For at kunne afspille YouTube-vidoer skal %1 bruge et eksternt program kaldet youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation>Komponenten skal opdateres ofte.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation>Du kan opdatere eller blot geninstallere SMPlayer. Installationsprogrammet downloader og installerer den seneste version.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation>Installer/opdater understøttelse af YouTube</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="209"/>
        <source>%1 can download and install this application for you.</source>
        <translation>%1 kan downloade og installere programmet for dig.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="210"/>
        <source>It will be downloaded from the official website and installed in %1.</source>
        <translation>Det vil blive downloadet fra det officielle websted og blive installeret i %1.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="211"/>
        <source>Would you like to proceeed?</source>
        <translation>Vil du fortsætte?</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="215"/>
        <location filename="../codedownloader.cpp" line="218"/>
        <source>Install YouTube support?</source>
        <translation>Installer understøttelse af YouTube?</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Generelt</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation>&amp;Tilføj ...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="166"/>
        <source>&amp;Players</source>
        <translation>&amp;Afspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="214"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="179"/>
        <source>Up</source>
        <translation>Op</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Afspilning</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation>Steder</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation>&amp;Sted:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation>&amp;Rediger ...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="225"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="249"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="262"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Tilføj foruddefinerede afspillere</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>&amp;Interface</source>
        <translation>&amp;Grænseflade</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="306"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stil:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="342"/>
        <source>Font:</source>
        <translation>Skrifttype:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="356"/>
        <source>C&amp;hange...</source>
        <translation>&amp;Vælg ...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Download video ved brug af en &amp;ekstern tjeneste</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="190"/>
        <source>Down</source>
        <translation>Ned</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="79"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Klik for at vælge en fil eller mappe</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Åbn i &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Gem link ...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Kopiér &amp;link til udklipsholder</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Åbn link i dette vindue</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Kopiér tekst til udklipsholder</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Åbn link i &amp;nyt vindue</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Afspil med</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Afspil &amp;lyd med</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>&amp;Afspil med %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>Afspil &amp;lyd med %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Afspil video med en &amp;webbrowser</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Rediger afspiller</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Navn:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Programfil:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametre:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Denne afspiller understøtter &amp;video-steder</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Denne afspiller kan afspille &amp;online-TV</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Foretrukket &amp;kvalitet:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Føj til &amp;menu:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video og lyd</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation>Rediger sted</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Navn:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation>URL for &amp;hjemmeside:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation>URL for &amp;søgning:</translation>
    </message>
</context>
</TS>
